Computes the log-likelihood of the scaled logit model at a given set of
parameter estimates (or the MLE if pars is not supplied). Either
fit or x, y and pars need to be supplied.
sclr_log_likelihood(fit = NULL, x = NULL, y = NULL, pars = NULL)An object returned by sclr. Or a list with
parameters, x and y entries corresponding to the parameter matrix, model
matrix and model response.
Model matrix. Will be taken from fit if fit is
provided.
Model response. Will be taken from fit if fit is
provided.
A named vector of parameter values. Will be taken from fit
if fit is provided.