Learn R Programming

sclr (version 0.1.0)

sclr_one_titre_data: Simulated one-titre antibody data

Description

A simulated dataset containing 6000 independent observations on antibody titres and the corresponding infection status. The data was simulated to resemble real influenza infection and haemagglutinin titre data.

Usage

sclr_one_titre_data

Arguments

Format

A data frame with 6000 observations and 4 variables:

logHI

haemagglutinin-inhibiting (HI) titre. True simulated titre on a log scale.

logHIcens

HI censored (observed) titre. The titre value on a log scale that would be observed in a real dataset with a typical HI assay.

logHImid

Midpoint of the interval (on a log scale) to which observed HI values are censored.

status

influenza infection status. 1 - infected. 0 - not infected

Model

The model behind the simulation was

$$\lambda * (1 - f(\beta_0 + \beta_1 * HI))$$

Where

  • \(f\) - Inverse logit function

  • \(\lambda\) = 0.25

  • \(\beta_0\) = 7.5

  • \(\beta_1\) = 2